@@ -616,7 +616,7 @@ create_archive_stream() {
 		"$TAR")
 			# --exclude "${package_dir}"/catalog 
 			# --exclude "${package_dir}"/catalog/\* 
-			"${TAR}" cf - ${TAR_FORMAT_OPTIONS} --files-from=- --no-recursion \
+			"${TAR}" cf - ${TAR_FORMAT_OPTIONS} --no-recursion --files-from=- \
 			${GNU_TAR_OWNER_OPTIONS} 
 			;;
 		"$PAX")
@@ -761,7 +761,7 @@ case "$GAWK" in
 /)
 	;;
 *)
-	$GAWK --version | head -1 | grep GNU | grep 3.1.2 1>/dev/null
+	$GAWK --version | head -1 | grep GNU | grep "Awk 3.1.2" 1>/dev/null
 	case $? in
 		0)
 			echo "checkdigest: Warning: GNU awk (gawk) 3.1.2 is broken" 1>&2
