@@ -15,6 +15,8 @@ awk -- '
 			if (done == 0) {
 				system("cat");
 				done=1;
+			} else {
+				printf("\n");
 			}
 		} else {
 			printf("%s\n", $0);
