@@ -35,7 +35,7 @@
 #define DEFAULT_PAX_REM "tar"
 #endif
 
-volatile int global_lastsig;
+/* volatile  */  /* int global_lastsig; */
 
 #define SWINSTALL_VOLATILE_SUFFIX	".swbisnew"
 #define SWREMOVE_VOLATILE_SUFFIX	".swbisold"
