@@ -78,9 +78,9 @@ typedef struct {
 	int cf_indexM;		/* the index j, in swi->swi_pkgM->swi_coM[i]->swi_coM[j] */
 } CISF_BASE;
 
-/* CISF_FILESET: this struct associates the location in INSTALLED with the
-   corresponding fileset object in (SWI*) namely the pointer held in
-   swi->swi_pkgM->swi_coM[i]->swi_coM[ii]  */
+/* CISF_FILESET: this struct associates the location in INSTALLED (or INDEX)
+   *SWHEADER object with the corresponding fileset object in (SWI*),
+   namely the pointer held in swi->swi_pkgM->swi_coM[i]->swi_coM[ii]  */
 
 typedef union /*struct*/ {
 	CISF_BASE cisf_baseM;
@@ -99,9 +99,12 @@ typedef struct {
 	CISF_BASE cisf_baseM;
 	SWI * swiM;		/* Main object, just to have it easily accessable */
 	SWI_PRODUCT * productM;	/* The installed product */
-	VPLOB * isetsM;		/* list of (*CISF_FILESET) pointers */
-	CISFBA * cbaM;		/* array of (CISF_BASE*) objects including this product
-				   and all the filesets */
+	VPLOB * isetsM;		/* USE: list of (*CISF_FILESET) pointers that are installed */
+	CISFBA * cbaM;		/* USE: array of (CISF_BASE*) objects including this product
+				     and *all* the filesets, wheather installed or selected
+				    for swinstall, it contains the list of scripts that have
+				   been run.
+				   */
 } CISF_PRODUCT;
 
 
@@ -303,7 +306,7 @@ swpl_retrieve_files(GB * G, SWI * swi, SWICOL * swicol, SWICAT_E * e, SWI_FILELI
 	int ofd, int ifd, int archive_fd, char * pax_write_command_key, int ls_fd, int ls_verbose, FILE_DIGS * digs);
 int swpl_ls_fileset_from_iscat(SWI * swi, int ofd, int ls_verbose, int * available_attributes, int skip_volatile, int check_contents);
 void swpl_bashin_detect(STROB * buf);
-int swpl_check_package_signatures(GB * G, SWI * swi, int sig_level);
+int swpl_check_package_signatures(GB * G, SWI * swi, int * NumChecked);
 char * swpl_make_package_signature(GB * G, SWI * swi);
 void swpl_set_detected_catalog_perms(SWI * swi, ETAR * etar, int tar_type);
 int swpl_get_catalog_perms(GB * G, SWI * swi, int ofd, int event_fd);
@@ -329,5 +332,9 @@ int swpl2_normalize_configure_script_results(SWI * swi, char * script_name, CISF
 void swpl_print_file_list_to_buf(SWI_FILELIST * fl, STROB * buf);
 int swpl_run_check_overwrite(GB * G, SWI_FILELIST * fl, SWI * swi, int ofd, char * target_path, int mem_fd);
 void swpl_write_chdir_catalog_fragment(STROB * tmp, char * catalog_path, char * id_str);
+void swpl_agent_fail_message(GB *G, char * current_arg, int status);
+void swpl_bashin_testsh(STROB * buf, char * shell);
+void swpl_bashin_posixsh(STROB * buf);
+int swpl_run_get_prelink_filelist(GB * G, SWICOL * swicol, int ofd, int * pfp_prelink_fd);
 
 #endif
