@@ -41,10 +41,12 @@ static char *rcsid = "$OpenBSD: strlcpy.c,v 1.5 2001/05/13 15:40:16 deraadt Exp
  * Returns strlen(src); if retval >= siz, truncation occurred.
  */
 size_t
-swlib__strlcpy(dst, src, siz)
+swlib__strlcpy(char * dst, const char * src, size_t siz)
+	/*
 	char *dst;
 	const char *src;
 	size_t siz;
+	*/
 {
 	register char *d = dst;
 	register const char *s = src;
