@@ -355,7 +355,7 @@ parseDefaultsFile(char * utility_name, char * defaults_filename,
 	uxfio_fcntl(uxfio_fd, UXFIO_F_SET_BUFACTIVE, UXFIO_ON);
 	uxfio_fcntl(uxfio_fd, UXFIO_F_SET_BUFTYPE, UXFIO_BUFTYPE_DYNAMIC_MEM);
 
-	if (strcmp(defaults_filename, "-") != 0)
+	if (strcmp(defaults_filename, SWBIS_STDIO_FNAME) != 0)
 		fd = open(defaults_filename, O_RDONLY, 0);
 	else
 		fd = STDIN_FILENO;
@@ -756,7 +756,8 @@ parse_options_file(struct extendedOptions * opta, char * filename,
 					char * util_name)
 {
 	int ret;
-	if (access(filename, R_OK) == 0) {
+
+	if (access(filename, R_OK) == 0 || strcmp(filename, SWBIS_STDIO_FNAME) == 0) {
 		ret = parseDefaultsFile(util_name, 
 			filename, opta, 1 /*doPreserveOptions */);
 	} else {
@@ -791,7 +792,7 @@ initialize_options_files_list(char * usethis)
 }
 
 int
-parse_options_files(struct extendedOptions * opta, char * option_files, 
+swextopt_parse_options_files(struct extendedOptions * opta, char * option_files, 
 				char * util_name, int reqd, int show_only)
 {
 	int do_check_access = 0;
@@ -813,7 +814,7 @@ parse_options_files(struct extendedOptions * opta, char * option_files,
 
 	file = strob_strtok(ktmp, strob_str(tmp), " ,\n\r");
 	while (file) {
-		if (do_check_access) {
+		if (do_check_access && strcmp(file, SWBIS_STDIO_FNAME)) {
 			if (access(file, R_OK) != 0) {
 				E_DEBUG("case");
 				if (reqd) {
