@@ -539,10 +539,10 @@ swheader_set_current_offset_p(SWHEADER * swheader, int *n)
 
 /* void * */
 /* (char * (*)(void *, int*)) */
-void * 
+F_GOTO_NEXT
 swheader_get_iter_function(SWHEADER * swheader)
 {
-	return (void*)(swheader->f_goto_next_);
+	return swheader->f_goto_next_;
 }
 
 o__inline__
@@ -966,7 +966,7 @@ swheader_fileobject2filehdr(SWHEADER * fileheader, struct new_cpio_header * file
 			(file_hdr->usage_maskM) |= TARU_UM_GID;
 			did_gid = 1;
 		} else if (strcmp(keyword, SW_A_link_source) == 0) {
-			ahsStaticSetTarLinkname(file_hdr, value);
+			ahsStaticSetPaxLinkname(file_hdr, value);
 			did_link_source = 1;
 		} else if (strcmp(keyword, SW_A_owner) == 0) {
 			E_DEBUG("owner");
