@@ -26,6 +26,8 @@
 
 #define NEWLINE_LEN 1
 
+#define MAGNITUDE_ARRAY_LEN 10
+
 /*
    The routines in this file parse or scan the parser output line 
    produced by the parser.  The stand-alone parser can make this
@@ -247,7 +249,7 @@ swheaderline_get_value_length(char *output_line)
 	int i;
 	char  * t, *p;
 	int n;
-	int mytens[6] = {0, 1, 10, 100, 1000, 10000};
+	int mytens[MAGNITUDE_ARRAY_LEN] = {0, 1, 10, 100, 1000, 10000, 100000, 1000000, 10000000, 100000000};
 
 	if (!isdigit((int)(*output_line))) {
 		fprintf(stderr, "bad parser output, value length not found\n"); 
@@ -260,11 +262,29 @@ swheaderline_get_value_length(char *output_line)
 	* return n;
 	*/
 
+
+	/*
+	 * The code below is a poor replacement for calling scanf.
+	 * another case of early optimization causing problems.
+	 */
+
 	n = 0;
 	t = output_line;
 	p = output_line;
 	while (*t && !isspace((int)(*t))) t++;
 	for (i = (int)(t - output_line); i > 0; i--) {
+		if (i >= MAGNITUDE_ARRAY_LEN) {
+			fprintf(stderr,
+				"fatal error: attribute value length in swheaderline_get_value_length() too big\n");
+			/*
+			 * JL  2018-11-1
+			 * FIXME? just exit for now,
+			 * the previous max length was 99999 which was exceeded by big packages,
+			 * this should be considerered a security fix since it led to buffer overrun.
+			 * Now really, really this should never happen.
+			 */
+			exit(33);
+		}
 		if (!isdigit(*p)) {
 			fprintf(stderr,
 		"internal error in swheaderline_get_value_length [%s]\n",
