@@ -242,6 +242,7 @@ int 		swlib_dir_compare(char * s1, char * s2, int compare_flag /* See SWC_FC_* *
 int		swlib_basename_compare(char * s1, char * s2);
 void 		swlib_toggle_leading_slash(char * mode, char * name, int *pflag);
 void		swlib_toggle_trailing_slash(char * mode, char * name, int *pflag);
+void		swlib_toggle_all_trailing_slash(char * mode, char * name, int *pflag);
 void 		swlib_squash_all_trailing_vnewline(char *path);
 void 		swlib_toggle_leading_dotslash(char * mode, char * name, int *pflag);
 void 		swlib_toggle_trailing_slashdot(char * mode, char * name, int *pflag);
@@ -318,5 +319,6 @@ mode_t		swlib_filestring_to_mode(char * str, int do_include_type);
 void		swlib_append_synct_eof(STROB * buf);
 pid_t		swlib_get_pax_header_pid(void);
 void		swlib_set_pax_header_pid(pid_t pd);
+char *		swlib_printable_safe_ascii(char * sf);
 
 #endif
