@@ -375,7 +375,7 @@ swpath_resolve_prepath(SWPATH * swpath, char *name)
 	char *p, *s;
 	if (swpath->swpath_p_prepath_)
 		return 0;
-	p = strstr(name, SW_CATALOG);
+	p = strstr(name, SW_A_catalog);
 	if (!p) {
 		/*
 		 * If name does not contain 'catalog'
@@ -582,7 +582,7 @@ swpath_form_catalog_path(SWPATH * swpath, STROB * buf)
 		return strob_str(buf);
 	if (strob_strlen(buf))
 		strob_strcat(buf, "/");
-	strob_strcat(buf, SW_CATALOG);
+	strob_strcat(buf, SW_A_catalog);
 	swpath__form_path1(swpath, buf, NULL);
 	return strob_str(buf);
 }
@@ -698,12 +698,17 @@ swpath_parse_path(SWPATH * swpath, char *name)
 	
 	for (i = 0; i < SWPATH_PARSE_CA; i++) ca[i] = (char *)(NULL);
 
+
+	/*  Remove legacy restriction 08Jun2014 */
+	/*
 	if (strlen(name) > 255) {
 		SWPATH_E_DEBUG(""); 
 		SWPATH_E_DEBUG2("%s", swpath_dump_string_s(swpath, ""));
 		SWPATH_E_DEBUG("EXIT swpath_parse_path"); 
 		return -1;
 	}
+	*/
+
 
 	strob_strcpy(swpath->buffer_, name);
 	swpath__slashclean(swpath, strob_str(swpath->buffer_));
@@ -742,7 +747,7 @@ swpath_parse_path(SWPATH * swpath, char *name)
 		SWPATH_E_DEBUG2("%s", \
 			swpath_parse_write_debug(dbuf, relative_n, ca));
 		compy = 1;
-		if (strcmp(ca[0], SW_CATALOG) != 0) {
+		if (strcmp(ca[0], SW_A_catalog) != 0) {
 			/*
 			* Not in catalog.
 			*/
@@ -770,7 +775,7 @@ swpath_parse_path(SWPATH * swpath, char *name)
 		SWPATH_E_DEBUG("relative_n == 2"); 
 		SWPATH_E_DEBUG2("%s", \
 				swpath_parse_write_debug(dbuf, relative_n, ca));
-		if (strcmp(ca[0], SW_CATALOG) == 0) {
+		if (strcmp(ca[0], SW_A_catalog) == 0) {
 			/*
 			* In catalog
 			*/
@@ -853,7 +858,7 @@ swpath_parse_path(SWPATH * swpath, char *name)
 		SWPATH_E_DEBUG2("%s", \
 			 swpath_parse_write_debug(dbuf, relative_n, ca));
 		SWPATH_E_DEBUG("-<>-"); 
-		if (strcmp(ca[0], SW_CATALOG) == 0) {
+		if (strcmp(ca[0], SW_A_catalog) == 0) {
 			/*
 			* In catalog
 			*/
@@ -994,7 +999,7 @@ swpath_parse_path(SWPATH * swpath, char *name)
 		SWPATH_E_DEBUG(""); 
 		SWPATH_E_DEBUG2("%s", \
 			swpath_parse_write_debug(dbuf, relative_n, ca));
-		if (strcmp(ca[0], SW_CATALOG) == 0) {
+		if (strcmp(ca[0], SW_A_catalog) == 0) {
 			/*
 			* In catalog section.
 			*/
