@@ -83,7 +83,7 @@ int swutil_doif_writef2(SWLOG * swutil, int write_at_level, char * format, ...);
 int swutil_writelogline(int logfd, char * sptr);
 int doif_i_writef(int verbose_level, int write_at_level, struct sw_logspec * logspec, int fd, char * format, va_list * pap);
 int cpp_doif_i_writef(int verbose_level, int write_at_level, struct sw_logspec * logspec, int fd,
-		char * cpp_FILE, int cpp_LINE, char * cpp_FUNCTION, char * format, va_list * pap);
+		char * cpp_FILE, int cpp_LINE, const char * cpp_FUNCTION, char * format, va_list * pap);
 int swutil_cpp_doif_writef(int verbose_level, int write_at_level, struct sw_logspec * logspec, int fd,
-		char * cpp_FILE, int cpp_LINE, char * cpp_FUNCTION, char * format, ...);
+		char * cpp_FILE, int cpp_LINE, const char * cpp_FUNCTION, char * format, ...);
 #endif
