@@ -47,7 +47,7 @@
 #include "swmain.h"
 #include "swgpg.h"
 
-YYSTYPE yylval;
+extern YYSTYPE yylval;
 static int verboseG;
 
 /*
