@@ -11,7 +11,7 @@
 #include "swcommon_options.h"
 int 
 main (int argc, char ** argv ) {
-   return taru_process_copy_in (STDIN_FILENO, STDOUT_FILENO);
+   return taru_process_copy_in ((TARU*)NULL, STDIN_FILENO, STDOUT_FILENO);
 }
 
 
