@@ -61,9 +61,9 @@ static void usage (char * progname, FILE*);
 static int G_OFD;
 
 
-YYSTYPE yylval;
+extern YYSTYPE yylval;
 int yydebug=0;
-int swlex_definition_file = SW_PSF;
+/* int swlex_definition_file = SW_PSF; */
 
 #define CHARTRUE  "true";
 
