@@ -32,9 +32,9 @@ static void sig_usr (int signo);
 static void usage (char * progname);
 
 
-YYSTYPE yylval;
+extern YYSTYPE yylval;
 int yydebug=0;
-int swlex_definition_file = SW_PSF;
+/* int swlex_definition_file = SW_PSF; */
 
 
 int 
