@@ -19,6 +19,11 @@
 #include "swcommon_options.h"
 #include "ls_list.h"
 
+
+static int HN = 0; /* Header Count Number for listing */
+
+
+
 static
 void
 usage(char * name)
@@ -34,6 +39,17 @@ usage(char * name)
 	fprintf(stderr, "  --help  Show this help.\n");
 	fprintf(stderr, "  -X, --pax-rdev-filter  reads tar archive on stdin and normalizes\n");
 	fprintf(stderr, "                         st_rdev values of non-device files to zero.\n");
+	fprintf(stderr, "  -I,--tar2tar tar to tar filter with decoding and re-writing.\n");
+	fprintf(stderr, "  -G,--tarheaderflags N  See taru/taru.h for values.\n");
+	fprintf(stderr, "     TARU_TAR_BE_LIKE_PAX = %d\n", TARU_TAR_BE_LIKE_PAX);
+	fprintf(stderr, "     TARU_TAR_NUMERIC_UIDS = %d\n", TARU_TAR_NUMERIC_UIDS);
+	fprintf(stderr, "     TARU_TAR_GNU_LONG_LINKS = %d\n", TARU_TAR_GNU_LONG_LINKS);
+	fprintf(stderr, "     TARU_TAR_GNU_GNUTAR = %d\n", TARU_TAR_GNU_GNUTAR);
+	fprintf(stderr, "     TARU_TAR_GNU_BLOCKSIZE_B1 = %d\n", TARU_TAR_GNU_BLOCKSIZE_B1);
+	fprintf(stderr, "     TARU_TAR_BE_LIKE_STAR = %d\n", TARU_TAR_BE_LIKE_STAR);
+	fprintf(stderr, "     TARU_TAR_FRAGILE_FORMAT = %d\n", TARU_TAR_FRAGILE_FORMAT);
+	fprintf(stderr, "     TARU_TAR_PAXEXTHDR = %d\n", TARU_TAR_PAXEXTHDR);
+	fprintf(stderr, "     TARU_TAR_PAXEXTHDR_MD = %d\n", TARU_TAR_PAXEXTHDR_MD);
 	fprintf(stderr, "  -D,--debug-dump  An ascii dump of the the tar headers.\n");
 	fprintf(stderr, "  -F,--file-list-only  Write the file list to stdout.\n");
 	fprintf(stderr, "  -L,--gnu-long-links  Store long file names like GNU tar. (non-POSIX).\n");
@@ -84,6 +100,7 @@ tr_char (void * src, int len, int new, int old)
 static
 void
 write_field(
+		struct  new_cpio_header * hdr,
 		int verbose, 
 		STROB * wf, 
 		int ofd, 
@@ -110,9 +127,9 @@ write_field(
 	}
 
 	if (verbose > 0) {
-		swlib_writef(ofd, wf, "%-12s[", fieldname);
+		swlib_writef(ofd, wf, "[%d] %-12s[", HN, fieldname);
 	} else {
-		swlib_writef(ofd, wf, "%s:=[", fieldname);
+		swlib_writef(ofd, wf, "[%d] %s:=[", HN, fieldname);
 	}	
 
 	write(ofd, (void*)buf, (size_t)buflen);
@@ -146,7 +163,7 @@ write_field(
 
 static
 int
-write_header_decode_format(STROB * wf, int ofd, char * buf, int buflen, int v)
+write_header_decode_format(struct  new_cpio_header * hdr, STROB * wf, int ofd, char * buf, int buflen, int v)
 {
 	char * p;
 	unsigned char * paxheader = (unsigned char*)buf;
@@ -160,38 +177,39 @@ write_header_decode_format(STROB * wf, int ofd, char * buf, int buflen, int v)
 	uintmax_to_chars(sum, paxSum, 7, POSIX_FORMAT, termch);
 	
 	strncpy(Mchksum, buf + THB_BO_chksum, sizeof(Mchksum));
-	swlib_writef(ofd, wf, "pax Format Archive Header: (length: %d)\n", buflen);
+	/* swlib_writef(ofd, wf, "pax Format Archive Header: (length: %d)\n", buflen); */
 
 	if ((p=strchr(Mchksum, ' '))) *p = '\0';
 	Mchksum[THB_FL_chksum] = '\0';
 
-	write_field(v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_name, THB_FL_name, "name");
-	write_field(v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_mode, THB_FL_mode, "mode");
-	write_field(v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_uid, THB_FL_uid, "uid");
-	write_field(v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_gid, THB_FL_gid, "gid");
-	write_field(v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_size, THB_FL_size, "size");
-	write_field(v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_mtime, THB_FL_mtime, "mtime");
-	write_field(v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_chksum, THB_FL_chksum, "chksum");
-	write_field(v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_typeflag, THB_FL_typeflag, "typeflag");
-	write_field(v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_linkname, THB_FL_linkname, "linkname");
-	write_field(v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_magic, THB_FL_magic, "magic");
-	write_field(v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_version, THB_FL_version, "version");
-	write_field(v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_uname, THB_FL_uname, "uname");
-	write_field(v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_gname, THB_FL_gname, "gname");
-	write_field(v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_devmajor, THB_FL_devmajor, "devmajor");
-	write_field(v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_devminor, THB_FL_devminor, "devminor");
-	write_field(v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_prefix, THB_FL_prefix, "prefix");
+	swlib_writef(ofd, wf, "[%d] Extended name=[%s]\n", HN, ahsStaticGetTarFilename(hdr));
+	swlib_writef(ofd, wf, "[%d] Extended linkname=[%s]\n", HN, ahsStaticGetTarLinkname(hdr));
+	write_field(hdr, v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_name, THB_FL_name, "name");
+	write_field(hdr, v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_mode, THB_FL_mode, "mode");
+	write_field(hdr, v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_uid, THB_FL_uid, "uid");
+	write_field(hdr, v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_gid, THB_FL_gid, "gid");
+	write_field(hdr, v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_size, THB_FL_size, "size");
+	write_field(hdr, v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_mtime, THB_FL_mtime, "mtime");
+	write_field(hdr, v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_chksum, THB_FL_chksum, "chksum");
+	write_field(hdr, v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_typeflag, THB_FL_typeflag, "typeflag");
+	write_field(hdr, v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_linkname, THB_FL_linkname, "linkname");
+	write_field(hdr, v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_magic, THB_FL_magic, "magic");
+	write_field(hdr, v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_version, THB_FL_version, "version");
+	write_field(hdr, v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_uname, THB_FL_uname, "uname");
+	write_field(hdr, v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_gname, THB_FL_gname, "gname");
+	write_field(hdr, v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_devmajor, THB_FL_devmajor, "devmajor");
+	write_field(hdr, v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_devminor, THB_FL_devminor, "devminor");
+	write_field(hdr, v, wf, ofd, paxSum, Mchksum, paxheader , THB_BO_prefix, THB_FL_prefix, "prefix");
 
 	return 0;
 }
 
 static
 int
-decode_filter(XFORMAT * package, int verbose)
+decode_filter(XFORMAT * package, int ifd, int verbose)
 {
 	int nullfd;
 	char * name;
-	int ifd;
 	int ret;
 	int aret;
 	int retval = -1;
@@ -201,6 +219,7 @@ decode_filter(XFORMAT * package, int verbose)
 	STROB * tmp;
 	char * extended_header;
 	int tarheader_length;
+	struct  new_cpio_header * hdr;
 
 	nullfd = open("/dev/null", O_RDWR);
 	file_hdr = (struct new_cpio_header*)(xformat_vfile_hdr(package));
@@ -208,7 +227,7 @@ decode_filter(XFORMAT * package, int verbose)
 	namebuf = strob_open(100);
 	tmp = strob_open(100);
 
-	ifd = STDIN_FILENO;
+	if (ifd < 0) ifd = STDIN_FILENO;
 	xformat_set_ifd(package, ifd);
 	ofd = nullfd;
 	xformat_set_ofd(package, ofd);
@@ -217,6 +236,7 @@ decode_filter(XFORMAT * package, int verbose)
 	
 	taruib_set_fd(nullfd);
 	retval = 1;
+	hdr = (struct new_cpio_header *)(xformat_vfile_hdr(package));
 	while ((ret = xformat_read_header(package)) > 0) {
 		if (xformat_is_end_of_archive(package)){
 			retval = 0;
@@ -224,16 +244,16 @@ decode_filter(XFORMAT * package, int verbose)
 		}
 		xformat_get_name(package, namebuf);
 		name = strob_str(namebuf);
-
 		extended_header = strob_str(package->taruM->headerM);
 		tarheader_length = package->taruM->header_lengthM;
 
-		write_header_decode_format(tmp, STDOUT_FILENO, extended_header, tarheader_length, verbose);
+		write_header_decode_format(hdr, tmp, STDOUT_FILENO, extended_header, tarheader_length, verbose);
 
 		taruib_clear_buffer();
 		aret = xformat_copy_pass(package, ofd, ifd);
 		if (aret < 0) goto error;
 		retval = 0;
+		HN++;
 	}
 	taruib_clear_buffer();
 
@@ -391,7 +411,10 @@ main (int argc, char ** argv ) {
 	XFORMAT * xformat;
 	int nullfd = open("/dev/null", O_RDWR, 0);
 	struct new_cpio_header * file_hdr;
-		
+	int tarheaderflags = 0;
+	int mode_tar2tar = 0;	
+
+	
 	xformat = xformat_open(-1, STDOUT_FILENO, arf_format);
 	
 	while (1)
@@ -401,6 +424,8 @@ main (int argc, char ** argv ) {
              {
                {"debug-dump", 0, 0, 'D'},
                {"test", 0, 0, 't'},
+               {"tar2tar", 0, 0, 'I'},
+               {"tarheaderflags", 1, 0, 'G'},
                {"numeric-owner", 0, 0, 'x'},
                {"gnu-long-links", 0, 0, 'L'},
                {"pax-rdev-filter", 0, 0, 'X'},
@@ -417,7 +442,7 @@ main (int argc, char ** argv ) {
                {0, 0, 0, 0}
              };
 
-             c = ugetopt_long (argc, argv, "tvaxLFXDH:", long_options, &option_index);
+             c = ugetopt_long (argc, argv, "tvaxLIFXDH:G:", long_options, &option_index);
              if (c == -1)
                  break;
 
@@ -430,6 +455,13 @@ main (int argc, char ** argv ) {
                case 'D':
 			dumpmode = 1;
 		 	break;
+               case 'I':
+			mode_tar2tar = 1;
+		 	break;
+               case 'G':
+			tarheaderflags = atoi (optarg);
+			xformat->taruM->taru_tarheaderflagsM = tarheaderflags;
+		 	break;
                case 't':
 			xformat_set_ofd(xformat, nullfd);
 			xformat->taruM->do_record_headerM = 1;
@@ -453,7 +485,7 @@ main (int argc, char ** argv ) {
                case 'F':
 			filelistonly = 1;
 			break;
-		case 'H':
+               case 'H':
 			if (taru_set_tar_header_policy(xformat->taruM, optarg, &arf_format))
 				exit(1);
 			break;
@@ -480,8 +512,8 @@ main (int argc, char ** argv ) {
 				unsigned long devno;
 				TARU * taru = taru_create();
 				ETAR * etar;
-				etar = etar_open(taru);
-				devno = swlib_atoul(optarg, (int *)NULL);	
+				etar = etar_open(taru->taru_tarheaderflagsM);
+				devno = swlib_atoul(optarg, (int *)NULL, (char**)NULL);	
 				etar_set_devmajor(etar, devno);
 				fprintf(stdout, "%s\n", (char*)(ETAR__HDR(etar)->devmajor));
 			}
@@ -493,8 +525,44 @@ main (int argc, char ** argv ) {
                }
 	}
 
+	if (mode_tar2tar) {
+		int tf_fd;
+		TARU * tf_taru;
+		int tf_ret;
+			
+		tf_fd = STDIN_FILENO;
+		if (optind < argc) {
+			if (strcmp(argv[optind], "-") == 0) {
+				tf_fd = STDIN_FILENO;
+			} else {
+				tf_fd = open(argv[optind], O_RDONLY);
+				if (tf_fd < 0) {
+					fprintf(stderr, "swbistar: %s\n", strerror(errno));
+					exit(1);	
+				}
+			}	
+		}
+		tf_taru = xformat->taruM;
+		tf_ret = taru_process_copy_out(tf_taru, tf_fd, STDOUT_FILENO,
+					NULL, NULL, arf_ustar, -1, -1, (intmax_t*)NULL, NULL);
+		if (tf_ret > 0) {
+			exit(0);
+		} else {
+			exit(1);
+		}
+	}
+
 	if (dumpmode) {
-			ret = decode_filter(xformat, verbose);
+			int xfd = -1;
+			if (optind < argc) {
+				xfd = open(argv[optind], O_RDONLY);
+				if (xfd < 0) {
+					fprintf(stderr, "swbistar: %s\n", strerror(errno));
+					exit(1);	
+				}
+			}
+			HN = 0;
+			ret = decode_filter(xformat, xfd, verbose);
 			exit(ret);
 	}
 
