@@ -41,12 +41,12 @@ typedef struct {
 	int length_;	/* current length, not including the last NULL */
 	int extra_;	/* the lookahead allocation amount */
 	int reserve_;	/* the total length of reserved memory */
-	char in_use_;
+	char in_use_;   /* Only used if S_MEM_CACHE is defined */
+	int fill_charM; /* character used to fill extra memory, default: '\0'*/
 } STROB;
 
 
 /* STROB INTERNAL FUNCTIONS */
-/* static STROB * strob_reopen_if ( size_t reqd_length, STROB * strb ); */
 
 
 /*-------------------------------------------------------------*/
@@ -55,7 +55,8 @@ typedef struct {
 STROB *		strob_open	(size_t initial_size);
 char *		strob_release	(STROB * strb);
 int 		strob_close	(STROB * strb);
-STROB *		strob_reopen	(size_t new_length, STROB * strb);
+STROB *		strob_reopen_fill_with (STROB * strb, size_t new_length, int fill_char);
+STROB *		strob_reopen	(STROB * strb,  size_t new_length);
 STROB *		strob_trunc	(STROB * strb);
 char *		strob_get_str	(STROB * strb);
 int 		strob_get_reserve(STROB * strb);
@@ -64,7 +65,6 @@ void 		strob_set_reserve(STROB * strb, int res);
 void 		strob_set_length(STROB * strb, int len);
 void 		strob_set_memlength(STROB * strb, int len);
 
-
 /*----*/
 STROB *		strob_cpy	(STROB * s, STROB * ct);
 STROB *		strob_cat	(STROB * s, STROB * ct);
@@ -88,22 +88,25 @@ void 		strob_chr	(STROB * strb, int ch);
 void 		strob_chr_index	(STROB * strb, int index, int ch);
 int 		strob_get_char	(STROB * strb, int index);
 char * 		strob_strcpy_at_offset(STROB * strb, int offset, char *str);
+char *		strob_strcat_at_offset(STROB * strb, int offset, char *str);
 
 void * 		strob_memcpy(STROB *strb, void * ct, size_t n);
-void *		strob_memcpy_at(STROB *strb, void * ct, size_t n, size_t offset);
+void *		strob_memcpy_at(STROB *strb, size_t offset, void * ct, size_t n);
 void		strob_append_hidden_null(STROB *strb);
 void *		strob_memmove(STROB *strb, void * ct, size_t n);
 void *		strob_memmove_to(STROB *strb, size_t dst_offset,
 						void * ct, size_t n);
 void *		strob_memcat(STROB *strb, void * ct, size_t n);
 int 		strob_sprintf(STROB * sb, int do_append, char * format, ...);
+int 		strob_sprintf_at(STROB * sb, int at_offset, char * format, ...);
 int 		strob_snprintf(STROB * sb, int do_append, size_t size, char * format, ...);
 int 		strob_vsprintf(STROB * sb, int do_append,
 						char * format, va_list ap);
 char *		strob_str	(STROB * strb);
 int 		strob_length	(STROB * strb);
 void *		strob_memset(STROB *strb, int c, size_t n);
-
+void		strob_set_fill_char(STROB *, int);
+int		strob_get_fill_char(STROB *);
 
 /* Depricated names */
 char *		strob_catstr	(STROB * strb, char *str);
