@@ -1,9 +1,64 @@
-#include "swuser_config.h"
+/*#include "swuser_config.h" */
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include "strob.h"
 
+
+
+static
+void
+test_chr_index(void) {
+/*
+make clean && gcc -g -Wall -c  teststrob.c && gcc -I.. -I../../include  -g -Wall -c strob.c &&  gcc -g strob.o teststrob.o && ./a.out
+*/
+
+STROB * s = strob_open(1);
+strob_set_fill_char(s, 48 /*(int)'0'*/);
+
+strob_chr_index(s, 80, (int)'3');
+fprintf(stdout, "[%s]\n", s->str_);
+
+strob_chr_index(s, 0, (int)'0');
+fprintf(stdout, "[%s]\n", s->str_);
+
+strob_chr_index(s, 1, (int)'1');
+fprintf(stdout, "[%s]\n", s->str_);
+
+strob_chr_index(s, 2, (int)'2');
+fprintf(stdout, "[%s]\n", s->str_);
+
+strob_chr_index(s, 3, (int)'3');
+fprintf(stdout, "[%s]\n", s->str_);
+
+strob_chr_index(s, 4, (int)'4');
+fprintf(stdout, "[%s]\n", s->str_);
+
+strob_chr_index(s, 5, (int)'5');
+fprintf(stdout, "[%s]\n", s->str_);
+
+strob_chr_index(s, 6, (int)'6');
+fprintf(stdout, "[%s]\n", s->str_);
+
+
+
+
+strob_chr_index(s, 4, (int)'4');
+fprintf(stdout, "[%s]\n", s->str_);
+strob_chr_index(s, 0, (int)'1');
+fprintf(stdout, "[%s]\n", s->str_);
+
+strob_chr_index(s, 20, (int)'0');
+fprintf(stdout, "[%s]\n", s->str_);
+strob_chr_index(s, 0, (int)'2');
+fprintf(stdout, "[%s]\n", s->str_);
+strob_chr_index(s, 20, (int)'2');
+fprintf(stdout, "[%s]\n", s->str_);
+strob_chr_index(s, 20, (int)'3');
+fprintf(stdout, "[%s]\n", s->str_);
+
+}
+
 main ()
 {
    STROB * strb;
@@ -14,6 +69,17 @@ main ()
    long s0,s1,d0,d1,offset;
 
 
+
+
+
+
+
+
+
+test_chr_index();
+
+exit(0);
+
    i=0;
    for(;;)
      {
@@ -70,7 +136,7 @@ main ()
             case '6':
               printf("strob_reopen : enter new size \n"); 
               scanf ("%d", &i);
-              if (! strob_reopen (i, strb ))
+              if (! strob_reopen (strb,i ))
                 printf ("reopen ERROR \n");
               break;
          }
