@@ -7,7 +7,7 @@
  * COPYING TERMS AND CONDITIONS
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
+ * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  
  */
 
 
@@ -30,7 +30,7 @@
 #include "strob.h"
 #include "uxfio.h"
 
-int swlib_is_escapable(char c);
+int swlib_is_ansi_escape(char c);
 static char * de_quote_it (char * src);
 
 int 
@@ -38,20 +38,16 @@ swparse_expand_n ( void **pa, int *newlen, char * src) {
    int n;
    int i=0, j=0;
    char *lp;
-   char * hasesc;
-   STROB * store = strob_open(2);
-   char * store_str = NULL;
+   STROB * store;
 
+	store = strob_open(2);
 	strob_strcpy(store, "");
 	src=de_quote_it(src);
 	lp = src;
    
-	hasesc = strchr(lp, '\\');
 	n=strlen(lp);
-	if (!hasesc) {
-   		strob_set_memlength(store, n+1);
-		store_str = strob_str(store);
-	}
+   	strob_set_memlength(store, n+1);
+
 	while ( i < n ) {
 		if ( *(lp + i)  == '\n' ) {
 			strob_chr_index(store, i+j,  '\\');
@@ -78,7 +74,7 @@ swparse_expand_n ( void **pa, int *newlen, char * src) {
 			        strob_chr_index(store, i+j, '\\');
 			        j++;
 			        strob_chr_index(store, i+j, '\\');
-			} else if ( !swlib_is_escapable ( *(lp + i + 1)) ) {
+			} else if ( !swlib_is_ansi_escape ( *(lp + i + 1)) ) {
 			        strob_chr_index(store, i+j, '\\');
 			        j++;
 			        strob_chr_index(store, i+j,  '\\');
@@ -86,11 +82,7 @@ swparse_expand_n ( void **pa, int *newlen, char * src) {
 			        strob_chr_index(store, i+j, *(lp + i));
 			}
 		} else {
-			if (!hasesc) {
-				store_str[i+j] = *(lp + i);
-			} else {
-		        	strob_chr_index(store, i+j, *(lp + i));
-			}
+		        strob_chr_index(store, i+j, *(lp + i));
 		}
 		i++;
 	}
