@@ -27,7 +27,7 @@
 #include "swlex_supp.h"
 #include "swlib.h"
 
-int swlex_definition_file;
+extern int swlex_definition_file;
 extern int swlex_debug;
 extern int swlex_inputfd;
 extern int swlex_errorcode;
