@@ -54,6 +54,34 @@ show_nopen(void)
 	return ret;
 }
 
+static
+int
+find_swdef_in_INFO(SWI_XFILE * xfile, char * tag, char * name)
+{
+	int ret;
+	char * p;
+	ret = -1;
+	p = swheader_get_object_by_tag(xfile->info_headerM, SW_A_control_file, tag);
+	E_DEBUG3("tag==[%s] name=[%s]", tag, name);
+	E_DEBUG2("p=[%p]", (void*)p);
+	if (p) {
+		ret = p - swheader_get_image_head(xfile->info_headerM);
+		E_DEBUG2("ret=%d", ret);
+		/* Sanity check */
+		if (ret < 0 ) {
+			fprintf(stderr, "%s: error: invalid value calculated in find_swdef_in_INFO: %d\n", swlib_utilname_get(), ret);
+			ret = -1;
+		}
+		if (ret >987654321) {
+			/* Sanity check because an INFO file is probably never this big.
+			 * Probably delete this in the future.
+			 */
+			fprintf(stderr, "%s: error: possible invalid value calculated in find_swdef_in_INFO: %d\n", swlib_utilname_get(), ret);
+			ret = -1;
+		}
+	}
+	return ret;
+}
 
 static 
 SWPATH_EX *
@@ -235,6 +263,7 @@ swi_xfile_add_control_script(SWI * swi, SWI_XFILE * xfile, char * name,
 {
 	SWI_CONTROL_SCRIPT * sc;
 	SWI_FILE_MEMBER * s;
+	int offset;
 
 	sc = swi_control_script_create();
 	s = swi_xfile_construct_file_member(xfile, name, fd,
@@ -242,6 +271,13 @@ swi_xfile_add_control_script(SWI * swi, SWI_XFILE * xfile, char * name,
 	sc->baseM.b_tagM = strdup(tag);
 	swi_com_check_clean_relative_path(sc->baseM.b_tagM);
 	sc->afileM = s;
+	sc->swi_xfileM = (void*)xfile;
+	offset = find_swdef_in_INFO(xfile, tag, name);
+	sc->INFO_offsetM = offset;
+	if (offset < 0) {
+		fprintf(stderr, "warning: find_swdef_in_INFO returned %d\n", offset);
+		/* should be an error in the future */
+	}
 	swi_add_script(xfile->swi_scM, sc);
 	return;
 }
@@ -644,7 +680,8 @@ swi_parse_file(
 	swi_com_assert_pointer((void*)(swi->swi_pkgM), __FILE__, __LINE__);
 	switch(swdeffile_type) {
 		case SWPARSE_SWDEF_FILETYPE_INFO:
-			E_DEBUG("case");
+			E_DEBUG("case SWPARSE_SWDEF_FILETYPE_INFO");
+			E_DEBUG2("xfile: %p", swi->swi_pkgM->current_xfileM);
 			swi_com_assert_pointer(
 				(void*)(swi->swi_pkgM->current_xfileM),
 					__FILE__, __LINE__);
@@ -908,11 +945,12 @@ swi_decode_catalog(SWI * swi)
 	}
 
 	while(name) {
-		E_DEBUG("");
+		E_DEBUG2("ENTERING LOOP: name=[%s]", name);
 		if (xformat_is_end_of_archive(xformat)){
 			/* 
 			 * error 
 			 */
+			E_DEBUG("EOA found before storage section: break");
 			retval = -1;
 			break;
 		}
@@ -926,7 +964,7 @@ swi_decode_catalog(SWI * swi)
 
 		swpath_ret = swpath_parse_path(swpath, name);
 		if (swpath_ret < 0) {
-			E_DEBUG("");
+			E_DEBUG("swpath_parse_path error");
 			fprintf(stderr, "%s: error parsing pathname [%s]\n", swlib_utilname_get(), name);
 			retval = -2;
 			break;
@@ -958,7 +996,7 @@ swi_decode_catalog(SWI * swi)
 				 */
 				E_DEBUG("");
 				strob_strcpy(tmp, swpath_get_prepath(swpath));
-				swlib_unix_dircat(tmp, SW_CATALOG);
+				swlib_unix_dircat(tmp, SW_A_catalog);
 				swi->exported_catalog_prefixM = strdup(strob_str(tmp));
 				swi_com_check_clean_relative_path(strob_str(tmp));
 			}
@@ -1020,13 +1058,14 @@ swi_decode_catalog(SWI * swi)
 			E_DEBUG("");
 			catalog_end_offset = uxfio_lseek(ifd, (off_t)0, SEEK_CUR);	
 			swi->swi_pkgM->catalog_end_offsetM = catalog_end_offset;
+			E_DEBUG2("catalog end offset = [%d]", swi->swi_pkgM->catalog_end_offsetM);
 		} else {
 			/*
 			 * Good.
 			 * Finished, read past catalog section
 			 * This is the first file of the storage section.
 			 */
-			E_DEBUG("");
+			E_DEBUG("STORAGE SECTION found: break");
 			swi->does_have_payloadM = 1;
 			break;
 		}
@@ -1035,11 +1074,12 @@ swi_decode_catalog(SWI * swi)
 		oldoffset = offset;
 		name = xformat_get_next_dirent(xformat, &st);
 		offset = uxfio_lseek(ifd, (off_t)0, SEEK_CUR);
-		E_DEBUG("");
+		E_DEBUG2("NAME=[%s]", name?name:"<NIL>");
 	}
 
 	E_DEBUG("");
 	if (retval < 0) {
+		E_DEBUG2("ERROR: retval = [%d]", retval);
 		return retval;
 	}
 	
@@ -1048,7 +1088,17 @@ swi_decode_catalog(SWI * swi)
 		/* Must not have a payload such as the
 		   catalog.tar file from the installed_software_catalog
 		   or a package with no files */
+
 		swi->does_have_payloadM = 0;
+
+		/* also we must set the swi->swi_pkgM->catalog_end_offsetM value
+		 * which is wrong at the present
+		 */
+
+		catalog_end_offset = uxfio_lseek(ifd, (off_t)0, SEEK_CUR);	
+		swi->swi_pkgM->catalog_end_offsetM = catalog_end_offset /* - xformat->eoaM */;
+		E_DEBUG2("NO PAYLOAD: NOW catalog end offset = [%d]", swi->swi_pkgM->catalog_end_offsetM);
+		E_DEBUG2("EOA bytes = [%d]", xformat->eoaM);
 	}
 
 	E_DEBUG("");
@@ -1076,7 +1126,17 @@ swi_decode_catalog(SWI * swi)
 	) {
 		return -8;
 	}
-	ret = swi_expand_shared_file_control_sripts(swi, swi->swi_pkgM->swi_coM[0]->xfileM);
+
+
+	if (swi->swi_pkgM && swi->swi_pkgM->swi_coM[0]) {
+		ret = swi_expand_shared_file_control_sripts(swi, swi->swi_pkgM->swi_coM[0]->xfileM);
+	} else {
+		/* This is an internal error and should never happen.
+		*/
+		fprintf(stderr, "%s: internal error swi->swi_pkgM && swi->swi_pkgM->swi_coM[0]\n", swlib_utilname_get());
+		ret = 0;
+	}
+
 	E_DEBUG("");
 	swi_com_assert_value(ret == 0, __FILE__, __LINE__);
 
@@ -1273,7 +1333,7 @@ swi_do_decode(SWI * swi, SWLOG * swutil,
 	format = arf_ustar;
 
 	/* Create the xformat object */
-        xformat = xformat_open( -1 /* STDIN_FILENO */, -1 /* target_fd1 */, format);
+        xformat = xformat_open( -1 /*STDIN_FILENO*/  , -1 /* target_fd1 */, format);
 
 	/* FIXME  the open policy described by flags may should be
 	   forced up a level so the top level utility can
@@ -1332,18 +1392,20 @@ swi_do_decode(SWI * swi, SWLOG * swutil,
 		/*
 		 * we'er installing an RPM, yeah!!! ;)
 		 */
-		set_opta(opta, SW_E_swbis_install_volatile, "true");
-		rpm_newname = get_opta(opta, SW_E_swbis_volatile_newname);
-		if (
-			swextopt_is_option_set(SW_E_swbis_volatile_newname, opta) == 0 &&
-			(!rpm_newname || !strlen(rpm_newname))
-		) {
-			set_opta(opta, SW_E_swbis_volatile_newname, ".rpmnew");
-		} else {
-			;
-			/*
-			 * Use the one the user set.
-			 */
+		if (opta) {
+			set_opta(opta, SW_E_swbis_install_volatile, "true");
+			rpm_newname = get_opta(opta, SW_E_swbis_volatile_newname);
+			if (
+				swextopt_is_option_set(SW_E_swbis_volatile_newname, opta) == 0 &&
+				(!rpm_newname || !strlen(rpm_newname))
+			) {
+				set_opta(opta, SW_E_swbis_volatile_newname, ".rpmnew");
+			} else {
+				;
+				/*
+				 * Use the one the user set.
+				 */
+			}
 		}
 	}
 
@@ -1517,7 +1579,7 @@ swi_make_fileset_file_list(SWI * swi, int product_num, int fileset_num, char * l
 
 	E_DEBUG("");
 	while ((object_line = swheader_get_next_object(infoheader, (int)(UCHAR_MAX), (int)UCHAR_MAX)) != NULL) {
-		E_DEBUG("");
+		E_DEBUG("---------------------------------------------------------------");
 		if (swheaderline_get_type(object_line) != SWPARSE_MD_TYPE_OBJ) {
 			SWLIB_ERROR("");
 			return NULL;
@@ -1531,16 +1593,16 @@ swi_make_fileset_file_list(SWI * swi, int product_num, int fileset_num, char * l
 			SWLIB_ERROR("unexpected null path");
 		}
 		/* need to check if its a volatile file */
+		E_DEBUG2("location=[%s]", location);
 		E_DEBUG2("path=[%s]", path);
-
+		E_DEBUG2("directory=[%s]", directory);
 
 		/* apply relocation */
 		if (strcmp(location, "/") != 0) {
-			E_DEBUG2("path=[%s]", path);
+			E_DEBUG2("APPLY LOCATION:  path=[%s]", path);
 			swlib_apply_location(relocated_path, path, location, directory);
-			E_DEBUG2("path=[%s]", path);
 			path =  strob_str(relocated_path);
-			E_DEBUG2("path=[%s]", path);
+			E_DEBUG2("AFTER path=[%s]", path);
 		}
 		/* SWLIB_ERROR2("path=[%s]", path); */
 
