@@ -224,7 +224,7 @@ int swi_do_decode(SWI * swi, SWLOG * swutil,
 	int source_fd0,
 	char * target_path,
 	char * source_path,
-	VPLOB * swpsecs,
+	VPLOB * swspecs,
 	char * target_host,
 	struct extendedOptions * opta,
 	int is_seekable,
