@@ -800,6 +800,8 @@ taru_write_archive_member_header(TARU * taru,
 	char * sbase;
 	ETAR * etar;
 	int tar_iflags_numeric_uids = (tarheaderflags & TARU_TAR_NUMERIC_UIDS); 
+	int needy_tar_header = 0;
+	int is_pax_header_allowed = 0;
 
 	E_DEBUG("BEGIN");
 	file_hdr = ahsStaticCreateFilehdr();
@@ -886,6 +888,48 @@ taru_write_archive_member_header(TARU * taru,
 			return -3;
 		}
 
+		/*
+		 * Determine if pax headers are allowed per the output format policy
+		 */
+
+		is_pax_header_allowed = ( tarheaderflags & TARU_TAR_PAXEXTHDR || 
+					    tarheaderflags & TARU_TAR_PAXEXTHDR_MD
+					);	
+
+		/*
+		 * Determine if tar header needs extended header to store any of the
+		 * other attributes and write a message if verbose.
+		 */
+
+		needy_tar_header = taru_fill_exthdr_needs_mask(file_hdr,
+					tarheaderflags,
+					is_pax_header_allowed,
+					/* verbose_messages */ 1);
+
+
+		/*
+		 * If needy, and overflow prohibited by the user
+		 * then return with error
+		 */
+
+		if (
+			needy_tar_header &&
+			is_pax_header_allowed == 0 &&
+			(tarheaderflags & TARU_TAR_NO_OVERFLOW)
+		) {
+			/*
+			 * process as error
+			 */
+			return -14;
+		}
+
+
+		/* 
+		 * initialize the file_hdr->extHeader_needs_maskM 
+		 */
+
+		file_hdr->extHeader_needs_maskM = needy_tar_header;
+
 
 		E_DEBUG2("do_gnu_long_link=%d", do_gnu_long_link);
 		E_DEBUG("");
@@ -905,7 +949,7 @@ taru_write_archive_member_header(TARU * taru,
  			 * is required due to the length limitation in the ustar
  			 * header field
  			 */
-			file_hdr->extHeader_needs_maskM = taru_fill_exthdr_needs_mask(file_hdr, tarheaderflags);
+			/* file_hdr->extHeader_needs_maskM = taru_fill_exthdr_needs_mask(file_hdr, tarheaderflags); */
 
 			/*
  			 * GNU LongLinks and PAX Ext headers are mutually exclusive.
