@@ -21,7 +21,7 @@
 #include "strob.h"
 #include "swlib.h"
 #include "swutilname.h"
-#include "taru.h"
+/* #include "taru.h" */
 #include "etar.h"
 #include "atomicio.h"
 	
@@ -30,12 +30,12 @@
 #define ETAR_UNSET_FILENAME "ETAR_UNSET_FILENAME"
 
 ETAR *
-etar_open (TARU * taru)
+etar_open (int flags)
 {
 	ETAR * etar;
 	etar = (ETAR *)malloc(sizeof(ETAR));
 	if (!etar) return etar;
-	etar->taruM = taru;
+	etar->etar_tarheaderflagsM = flags;
 	etar->timeM = time(NULL);
 	etar->tar_hdrM = (char*)malloc((size_t)(HEADER_ALLOC));
 	memset(etar->tar_hdrM, '\0', (size_t)(HEADER_ALLOC));
@@ -191,7 +191,7 @@ etar_set_size_from_fd(ETAR * etar, int fd, int * newfd)
 int
 etar_set_pathname(ETAR * etar, char * pathname)
 {
-	return taru_set_new_name(etar->taruM, HDR(etar), -1, pathname);
+	return taru_set_new_name(HDR(etar), -1, pathname, etar->etar_tarheaderflagsM);
 }
 
 int
@@ -225,7 +225,7 @@ etar_set_gname(ETAR * etar, char * name)
 void
 etar_set_chksum(ETAR * etar)
 {
-	taru_set_tar_header_sum(etar->taruM, HDR(etar));
+	taru_set_tar_header_sum(HDR(etar), etar->etar_tarheaderflagsM);
 }
 
 void
