@@ -6,6 +6,11 @@
 
 #include "swuser_config.h"
 #include <sys/stat.h>
+
+#ifdef HAVE_SYS_SYSMACROS_H
+#include <sys/sysmacros.h>
+#endif
+
 #include "cpiohdr.h"
 #include "tarhdr.h"
 #include "filetypes.h"
