@@ -37,11 +37,6 @@
 #include "debug_config.h"
 #include "atomicio.h"
 
-static int g_taruib_gst_overflow_releaseM;
-static int g_taruib_gst_fdM;
-static int g_taruib_gst_lenM;
-static char g_taruib_gst_bufferM[TARU_BUFSIZ_RES];
-	
 static char * md5sum_adjunct_pattern[3] = {
 	"catalog/*/adjunct_md5sum",
 	"*/catalog/*/adjunct_md5sum",
@@ -291,11 +286,17 @@ do_sig_safety_checks(int memfd, int sigsize, int whichsig)
 	int foundchar = 0;
 	int which_offset = 0;
 	int nsig;
+	int start_sig;
+	int end_sig;
 
+	E_DEBUG("ENTERING");
 	if (uxfio_get_dynamic_buffer(memfd, &data, NULL, &data_len) < 0) {
 		return -1;
 	}
 
+	E_DEBUG2("data_len=[%d]", data_len);
+
+
 	if (whichsig == 0) {
 		/*
 		* sanity check
@@ -305,69 +306,88 @@ do_sig_safety_checks(int memfd, int sigsize, int whichsig)
 		}
 	}
 
+	E_DEBUG("");
 	if (whichsig > 0) {
 		/*
 		* sanity check
 		*/
 		if (data_len < (whichsig * sigsize)) {
+			fprintf(stderr, "%s: invalid signature number specified\n", swlib_utilname_get());
 			return -4;
 		}
 	}
 
+	E_DEBUG("");
 	if (data_len % sigsize) {
 		/*
 		* sanity check
 		*/
+		E_DEBUG("error");
 		return -5;
 	}
 
 	nsig = data_len / sigsize;
+	E_DEBUG2("number of sigs are [%d]", nsig);
 
 	if (nsig < 1) {
 		/*
 		* sanity check
 		*/
+		E_DEBUG("error");
 		return -6;
 	}
 
+
+
 	if (whichsig == 0) {
+		E_DEBUG("whichsig = 0");
 		which_offset = (nsig-1) * sigsize;
+		start_sig = end_sig = nsig;
 	} else if (whichsig > 0) {
+		E_DEBUG("whichsig > 0");
 		which_offset = (whichsig-1) * sigsize;
+		start_sig = end_sig = whichsig;
 	} else {
-		return -7;
+		E_DEBUG("whichsig < 0");
+		start_sig=1;
+		end_sig = nsig;	
 	}
 
-	s = data + which_offset;
-	while (cnt < sigsize) {
-		switch ((int)(*s)) {
-			case '\0':
-				if (!foundchar) {
-					fprintf(stderr,
-						"Corrupt char in sigfile\n");
-					return 3;
-				}
-				foundnull++;
-				break;
-
-			default:
-				if (foundnull) {
-					fprintf(stderr,
-						"Corrupt char in sigfile\n");
-					return 2;
-				}
-				if ( !isprint((int)(*s)) && 
-						*s != '\x0a' && *s != '\x0d') {
-					fprintf(stderr, 
-						"Corrupt char in sigfile\n");
-					return 1;
-				}
-				foundchar++;
-				break;
+	while (start_sig++ <= end_sig) {
+		s = data + ((start_sig-2) * sigsize);
+		E_DEBUG2("((start_sig-2) * sigsize) = %d", ((start_sig-2) * sigsize));
+		while (cnt < sigsize) {
+			switch ((int)(*s)) {
+				case '\0':
+					if (!foundchar) {
+						fprintf(stderr,
+							"%s: Corrupt char in sigfile\n", swlib_utilname_get());
+						return 3;
+					}
+					foundnull++;
+					break;
+	
+				default:
+					if (foundnull) {
+						fprintf(stderr,
+							"%s: Corrupt char in sigfile\n", swlib_utilname_get());
+						return 2;
+					}
+					if ( !isprint((int)(*s)) && 
+							*s != '\x0a' && *s != '\x0d') {
+						fprintf(stderr, 
+							"%s: Corrupt char in sigfile\n", swlib_utilname_get());
+						return 1;
+					}
+					foundchar++;
+					break;
+			}
+			s++;
+			cnt++;
 		}
-		s++;
-		cnt++;
 	}
+
+
 	/*
 	 * A trailing NUL is optional
 	 */
@@ -683,8 +703,8 @@ taruib_write_signedfile_if_i(void * vp, int ofd,
 
 				if (sighdr_addr == NULL ||
 					(
-					sighdr_len != 512 &&
-					sighdr_len != 1024
+					sighdr_len != 512 /*  && */
+					/* sighdr_len != 1024   BAD CHECK, confused with .../signature size.*/
 					)
 					) {
 					/* Sanity check, error.  */
@@ -844,13 +864,13 @@ truncate_sigfile(char * sigfile)
 	close(sigfd);
 	return;
 }
-			
+
+
 static
 int
-write_selected_sig(int sigfd, int memfd, int whichsig, int sigsize)
+write_selected_sig_i(int sigfd, int memfd, int whichsig, int sigsize)
 {
-
-	int len;
+	/* int len; */
 	int offset;
 	int ret;
 	char * s;
@@ -858,17 +878,8 @@ write_selected_sig(int sigfd, int memfd, int whichsig, int sigsize)
 	char * nsig;
 
 	if (whichsig == 0) {
-		/*
-		* Last signature
-		*/
-		len = uxfio_lseek(memfd, 0, SEEK_END);
-		if (len < 0) return -2;
-		offset = len - sigsize;
+		return -1;
 	} else if (whichsig < 0) {
-		/*
-		* All signatures.
-		*/
-		; /* not yet supported */	
 		return -1;
 	} else {
 		/*
@@ -903,6 +914,41 @@ write_selected_sig(int sigfd, int memfd, int whichsig, int sigsize)
 }
 
 
+static
+int
+write_selected_sig(int sigfd, int memfd, int whichsig, int sigsize)
+{
+	int len;
+	int start_sig, end_sig;
+	int ret;
+	
+	len = uxfio_lseek(memfd, 0, SEEK_END);
+	if (len < 0) return -2;
+
+	end_sig = len / sigsize;
+
+	if (whichsig == 0) {
+		/* Last sig */
+		start_sig = end_sig;
+	} else if (whichsig < 0) {
+		/* all sigs */
+		start_sig = 1;
+	} else {
+		/*
+		* 1 is first, 2 is second,...
+		*/
+		start_sig = whichsig;
+		end_sig = whichsig;
+	}
+	while (start_sig++ <= end_sig) {
+		ret = write_selected_sig_i(sigfd, memfd, start_sig-1, sigsize);
+		if (ret < 0) return -1;
+	}
+	return 0;
+}
+
+
+
 static
 void
 report_dig_error(STROB * buf, int msgfd, int efd, char * digname, int dlen, int verbose)
@@ -963,6 +1009,7 @@ taruib_write_signedfile_if(void * vp, int ofd, char * sigfile,
 
 
 	E_DEBUG("ENTERING");
+	E_DEBUG2("ENTERING whichsig=[%d]", whichsig);
 	msgfd = logger_fd;
 	efd = STDERR_FILENO;
 	tmp = strob_open(32);
@@ -1027,10 +1074,12 @@ taruib_write_signedfile_if(void * vp, int ofd, char * sigfile,
 			/*
 			* error
 			*/
-			E_DEBUG2("exiting with value cret=%d", -cret);
+			E_DEBUG2("exiting with value cret=%d", cret);
 			truncate_sigfile(sigfile);
-			if (cret == 0) cret = -1;
-			_exit(-cret);
+			if (cret == 0)
+				_exit(TARUIB_TEXIT_ERROR_CONDITION_0);
+			else
+				_exit(TARUIB_TEXIT_ERROR_CONDITION_1);
 		}
 		sigsize = cret;
 		uxfio_fcntl(ifd, UXFIO_F_SET_BUFACTIVE, UXFIO_OFF);
@@ -1044,7 +1093,7 @@ taruib_write_signedfile_if(void * vp, int ofd, char * sigfile,
 					fprintf(stderr, "taruib_write_signedfile_if:"
 						" error from xformat_copy_pass2\n");	
 					truncate_sigfile(sigfile);
-					_exit(31);
+					_exit(TARUIB_TEXIT_ERROR_CONDITION_2);
 				}
 				E_DEBUG("out of xformat_copy_pass2");
 			}
@@ -1053,11 +1102,12 @@ taruib_write_signedfile_if(void * vp, int ofd, char * sigfile,
 		E_DEBUG("entering taruib_write_pass_files");
 		cret = taruib_write_pass_files(vp, digfile[1], -1);
 		E_DEBUG2("taruib_write_pass_files exited cret=%d", cret);
-		if (cret < 0) _exit(41);
+		if (cret < 0) 
+			_exit(TARUIB_TEXIT_ERROR_CONDITION_3);
 		E_DEBUG2("sigsize=%d", sigsize);
 		if (sigsize == 512) _exit(TARUIB_TEXIT_512);
 		if (sigsize == 1024) _exit(TARUIB_TEXIT_1024);
-		_exit(1);
+		_exit(TARUIB_TEXIT_ERROR_CONDITION_4);
 	}
 	close(filesizefd[1]);
 	close(sha1dig[1]);
@@ -1155,7 +1205,13 @@ taruib_write_signedfile_if(void * vp, int ofd, char * sigfile,
 	
 	E_DEBUG("");
 	memfd = swlib_open_memfd();
-	swlib_pipe_pump(memfd, sigpipefd[0]);
+	ret = swlib_pipe_pump(memfd, sigpipefd[0]);
+	if (ret < 0) {
+		fprintf(stderr, "taruib_write_signedfile_if:"
+			" internal error reading sigpipdfd,  ret=%d\n", ret);
+		return 18;
+	}
+	E_DEBUG2("ret from sigpipefd is [%d]", ret);
 
 	if (uxfio_lseek(memfd, 0, SEEK_SET) != 0) {
 		fprintf(stderr, "taruib_write_signedfile_if: internal error : uxfio_lseek\n");
@@ -1170,10 +1226,10 @@ taruib_write_signedfile_if(void * vp, int ofd, char * sigfile,
 	close(filesizefd[0]);
 	close(sha1dig[0]);
 	close(sha512dig[0]);
-	swlib_wait_on_all_pids(pid, 1, status, WNOHANG, 0);
+	swlib_wait_on_all_pids(pid, 1, status, 0 /*was WNOHANG, oops */, 0);
 	if (WIFEXITED(status[0]) == 0) {
-		fprintf(stderr, "swbis: pid[0] exited abnormally : exitval = [%d]\n",
-			WEXITSTATUS(status[0]));
+		fprintf(stderr, "%s: %d exited abnormally : status = %d\n",
+			swlib_utilname_get(), (int)pid[0], status[0]);
 		return 9;
 	}
 	ifret = WEXITSTATUS(status[0]);
@@ -1189,11 +1245,11 @@ taruib_write_signedfile_if(void * vp, int ofd, char * sigfile,
 	E_DEBUG2("ifret=%d", ifret);
 	if (ifret != TARUIB_TEXIT_512 && ifret != TARUIB_TEXIT_1024) {
 		/*
-		* abnormal error.
+		* abnormal exit.
 		*/
 		E_DEBUG("");
-		fprintf(stderr, "swbis: pid[0] exited with status=%d indicating error.\n",
-			WEXITSTATUS(status[0]));
+		fprintf(stderr, "%s: pid[%d] exited with ifret=%d\n",
+			swlib_utilname_get(), (int)pid[0], ifret);
 		return 13;
 	}
 
@@ -1329,7 +1385,7 @@ taruib_write_signedfile_if(void * vp, int ofd, char * sigfile,
 		return 14;
 	}
 
-	E_DEBUG("");
+	E_DEBUG2("whichsig=%d", whichsig);
 	if (pri_ret == 0) {
 		/*
 		* Look for evidence of trojan data hiding in the
@@ -1337,7 +1393,7 @@ taruib_write_signedfile_if(void * vp, int ofd, char * sigfile,
 		*/
 		E_DEBUG("");
 		if (do_sig_safety_checks(memfd, sigsize, whichsig)) {
-			fprintf(stderr, "corrupt signature file\n");
+			fprintf(stderr, "%s: error reading signature block\n", swlib_utilname_get());
 			pri_ret = 10;
 		} else {
 			/*
