@@ -5,6 +5,8 @@
 #include <sys/stat.h>
 #include "swparser_global.h"
 #include "xformat.h"
+#include "swevents_array.h"
+#include "swcommon_options.h"
 
 int 
 main (int argc, char ** argv ) {
