@@ -27,6 +27,8 @@
 #include <signal.h>
 #include "swpath.h"
 #include "uxfio.h"
+#include "vplob.h"
+#include "shcmd.h"
 #include "taru.h"
 #include "taruib.h"
 
@@ -56,7 +58,7 @@
 #define UINFILE_SAVE 		1
 
 #define UINFILE_MAGIC_gz 	"\x1f\x8b\x08\x00"
-#define UINFILE_MAGIC_Z 	"\x1f\x9d\x90\x00"
+#define UINFILE_MAGIC_Z 	"\x1f\x9d\x90"
 #define UINFILE_MAGIC_rpm 	"\xed\xab\xee\xdb"
 #define UINFILE_MAGIC_bz2 	"\x42\x5a\x68"
 #define UINFILE_MAGIC_lzma 	"\x5d\x00\x00\x80"
@@ -99,8 +101,9 @@
 #define UINFILE_DETECT_UNCPIO			(1 << 17) /* Convert to tar format */
 #define UINFILE_DETECT_DEB_DATA			(1 << 18) /* return fd to data.tar.gz */
 #define UINFILE_DETECT_DEB_CONTROL		(1 << 19) /* return fd to control.tar.gz */
-#define UINFILE_DETECT_DEB_CONTEXT		(1 << 20) /* return fd to control.tar.gz */
+#define UINFILE_DETECT_DEB_CONTEXT	(1 << 20) /* return fd to control.tar.gz */
 #define UINFILE_DETECT_SLACK		(1 << 21) /* return fd to control.tar.gz */
+#define UINFILE_DETECT_RECOMPRESS	(1 << 22) /* Construct the re-compress SHCMD command vector */
 
 /* this order is the same as the arf_format enumeration in GNU cpio */
 #define UNKNOWN_FILEFORMAT		0	/* arf_unknown		*/
@@ -129,7 +132,6 @@ typedef struct {
    char type_revisionM[12]; /* Package Format Revision */
    int ztypeM;		/* Compression Format */
    int layout_typeM;	/* Layout type */
-   char * zcat_cmdM;
    int did_dupeM;
    struct new_cpio_header * file_hdrM;
    int pidlistM[20];
@@ -146,6 +148,7 @@ typedef struct {
    unsigned char * slackheaderM; /* leading ./ archive member */
    char * pathname_prefixM;
    char * slack_nameM;
+   VPLOB * recompress_commandsM;
 } UINFORMAT;
 
 int     uinfile_get_layout_type(UINFORMAT * uinformat);
@@ -164,5 +167,5 @@ char *	uinfile_debug		(UINFORMAT * uin, char * prefix);
 int 	uinfile_wait_on_pid	(UINFORMAT * uinformat, int pid, int flag, int * status);
 int 	uinfile_wait_on_all_pid (UINFORMAT * uinformat, int flag);
 int	uinfile_opendup_with_name(int xdupfd, mode_t mode, UINFORMAT ** uinformat, int oflags, char * name);
-
+SHCMD ** uinfile_get_recompress_vector(UINFORMAT * uinformat);
 #endif
